@@ -5,7 +5,9 @@ package Cobol::Compiler::ID;
 sub new {
 	my ($class, $id) = @_;
 
-	my $self = { prevTokens => (),
+	my $self = { 
+			codeString => $id,
+			prevTokens => (), ### these are Token or derived instances
 			installer => Cobol::Compiler::TokenInstaller->new, };
 	
 	### FIXME NOTE call this $self->{installer}->install($self);
@@ -21,4 +23,10 @@ sub install_token {
 	push(@{ $self->{prevTokens} }, $installer->getToken; );
 }
 
+sub getCodeString {
+	my ($self) = @_;
+
+	return $self->{codeString};
+
+}
 1;
